# OperatorArgument

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**is_context** | **bool** |  | [optional] 
**value** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


